==> carbon-component-mapper-3.11.4.tgz: package/esm/select/select.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _typeof from "@babel/runtime/helpers/typeof";
import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import DataDrivenSelect from '@data-driven-forms/common/select';
import fnToString from '@data-driven-forms/common/utils/fn-to-string';
import CarbonSelect from "carbon-components-react/es/components/Select/Select.js";
import MultiSelect from "carbon-components-react/es/components/MultiSelect/MultiSelect.js";
import SelectItem from "carbon-components-react/es/components/SelectItem/SelectItem.js";
import ComboBox from "carbon-components-react/es/components/ComboBox/ComboBox.js";
import SelectItemGroup from "carbon-components-react/es/components/SelectItemGroup/SelectItemGroup.js";
import prepareProps from '../prepare-props';

var onChangeWrapper = function onChangeWrapper(onChange) {
  return function (_ref) {
    var selectedItem = _ref.selectedItem,
        selectedItems = _ref.selectedItems;
    return onChange(selectedItems || selectedItem);
  };
};

export var getMultiValue = function getMultiValue(value, options) {
  return (Array.isArray(value) ? value : value ? [value] : []).map(function (item) {
    return _typeof(item) === 'object' ? item : options.find(function (_ref2) {
      var value = _ref2.value;
      return value === item;
    });
  });
};

var renderOptions = function renderOptions(options) {
  return options.map(function (option, index) {
    var options = option.options,
        rest = _objectWithoutProperties(option, ["options"]);

    if (options) {
      return /*#__PURE__*/React.createElement(SelectItemGroup, _extends({
        key: rest.value || index,
        text: rest.label
      }, rest), renderOptions(options));
    }

    return /*#__PURE__*/React.createElement(SelectItem, _extends({
      key: rest.value || index,
      text: rest.label
    }, rest));
  });
};

var ClearedMultiSelectFilterable = function ClearedMultiSelectFilterable(_ref3) {
  var invalidText = _ref3.invalidText,
      hideSelectedOptions = _ref3.hideSelectedOptions,
      noOptionsMessage = _ref3.noOptionsMessage,
      onInputChange = _ref3.onInputChange,
      options = _ref3.options,
      isFetching = _ref3.isFetching,
      invalid = _ref3.invalid,
      isMulti = _ref3.isMulti,
      classNamePrefix = _ref3.classNamePrefix,
      closeMenuOnSelect = _ref3.closeMenuOnSelect,
      onChange = _ref3.onChange,
      originalOnChange = _ref3.originalOnChange,
      carbonLabel = _ref3.carbonLabel,
      placeholder = _ref3.placeholder,
      isDisabled = _ref3.isDisabled,
      rest = _objectWithoutProperties(_ref3, ["invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "isMulti", "classNamePrefix", "closeMenuOnSelect", "onChange", "originalOnChange", "carbonLabel", "placeholder", "isDisabled"]);

  return /*#__PURE__*/React.createElement(MultiSelect.Filterable, _extends({
    disabled: isDisabled
  }, rest, {
    placeholder: carbonLabel || placeholder,
    onChange: onChangeWrapper(onChange),
    titleText: rest.labelText,
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText,
    items: options,
    initialSelectedItems: getMultiValue(rest.value, options)
  }));
};

ClearedMultiSelectFilterable.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  isDisabled: PropTypes.bool
};

var ClearedMultiSelect = function ClearedMultiSelect(_ref4) {
  var invalidText = _ref4.invalidText,
      hideSelectedOptions = _ref4.hideSelectedOptions,
      noOptionsMessage = _ref4.noOptionsMessage,
      onInputChange = _ref4.onInputChange,
      options = _ref4.options,
      isFetching = _ref4.isFetching,
      invalid = _ref4.invalid,
      isMulti = _ref4.isMulti,
      classNamePrefix = _ref4.classNamePrefix,
      closeMenuOnSelect = _ref4.closeMenuOnSelect,
      onChange = _ref4.onChange,
      originalOnChange = _ref4.originalOnChange,
      carbonLabel = _ref4.carbonLabel,
      placeholder = _ref4.placeholder,
      isDisabled = _ref4.isDisabled,
      rest = _objectWithoutProperties(_ref4, ["invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "isMulti", "classNamePrefix", "closeMenuOnSelect", "onChange", "originalOnChange", "carbonLabel", "placeholder", "isDisabled"]);

  return /*#__PURE__*/React.createElement(MultiSelect, _extends({
    disabled: isDisabled
  }, rest, {
    label: carbonLabel || placeholder,
    onChange: onChangeWrapper(onChange),
    titleText: rest.labelText,
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText,
    items: options,
    initialSelectedItems: getMultiValue(rest.value, options)
  }));
};

ClearedMultiSelect.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  isDisabled: PropTypes.bool
};

var getSelectValue = function getSelectValue(value, isMulti) {
  return isMulti ? value : Array.isArray(value) ? value[0] : value;
};

var ClearedSelect = function ClearedSelect(_ref5) {
  var isSearchable = _ref5.isSearchable,
      isClearable = _ref5.isClearable,
      isDisabled = _ref5.isDisabled,
      isMulti = _ref5.isMulti,
      invalidText = _ref5.invalidText,
      hideSelectedOptions = _ref5.hideSelectedOptions,
      noOptionsMessage = _ref5.noOptionsMessage,
      onInputChange = _ref5.onInputChange,
      options = _ref5.options,
      isFetching = _ref5.isFetching,
      invalid = _ref5.invalid,
      classNamePrefix = _ref5.classNamePrefix,
      closeMenuOnSelect = _ref5.closeMenuOnSelect,
      originalOnChange = _ref5.originalOnChange,
      placeholder = _ref5.placeholder,
      value = _ref5.value,
      rest = _objectWithoutProperties(_ref5, ["isSearchable", "isClearable", "isDisabled", "isMulti", "invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "classNamePrefix", "closeMenuOnSelect", "originalOnChange", "placeholder", "value"]);

  return /*#__PURE__*/React.createElement(CarbonSelect, _extends({
    value: getSelectValue(value, isMulti),
    disabled: isFetching
  }, rest, {
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText
  }), isFetching && /*#__PURE__*/React.createElement(SelectItem, {
    text: placeholder,
    value: ''
  }), renderOptions(options));
};

ClearedSelect.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  isSearchable: PropTypes.bool,
  isClearable: PropTypes.bool,
  value: PropTypes.any
};

var getComboInitialValue = function getComboInitialValue(value) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var result = Array.isArray(value) ? value[0] : value;
  return _typeof(result) === 'object' ? result : options.find(function (_ref6) {
    var value = _ref6.value;
    return value === result;
  }) || result;
};
/**
 * Combobox cannot be multi value
 */


var ClearedSelectSearchable = function ClearedSelectSearchable(_ref7) {
  var isSearchable = _ref7.isSearchable,
      isClearable = _ref7.isClearable,
      isDisabled = _ref7.isDisabled,
      isMulti = _ref7.isMulti,
      invalidText = _ref7.invalidText,
      hideSelectedOptions = _ref7.hideSelectedOptions,
      noOptionsMessage = _ref7.noOptionsMessage,
      onInputChange = _ref7.onInputChange,
      _ref7$options = _ref7.options,
      options = _ref7$options === void 0 ? [] : _ref7$options,
      isFetching = _ref7.isFetching,
      invalid = _ref7.invalid,
      classNamePrefix = _ref7.classNamePrefix,
      closeMenuOnSelect = _ref7.closeMenuOnSelect,
      originalOnChange = _ref7.originalOnChange,
      placeholder = _ref7.placeholder,
      labelText = _ref7.labelText,
      onChange = _ref7.onChange,
      rest = _objectWithoutProperties(_ref7, ["isSearchable", "isClearable", "isDisabled", "isMulti", "invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "classNamePrefix", "closeMenuOnSelect", "originalOnChange", "placeholder", "labelText", "onChange"]);

  return /*#__PURE__*/React.createElement(ComboBox, _extends({
    disabled: isFetching
  }, rest, {
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText,
    initialSelectedItem: getComboInitialValue(rest.value, options),
    items: options,
    placeholder: placeholder,
    titleText: labelText,
    onChange: onChangeWrapper(onChange)
  }));
};

ClearedSelectSearchable.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  isSearchable: PropTypes.bool,
  isClearable: PropTypes.bool,
  labelText: PropTypes.string
};

var Select = function Select(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      isMulti = _useFieldApi.isMulti,
      isSearchable = _useFieldApi.isSearchable,
      isClearable = _useFieldApi.isClearable,
      loadOptions = _useFieldApi.loadOptions,
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      rest = _objectWithoutProperties(_useFieldApi, ["isMulti", "isSearchable", "isClearable", "loadOptions", "input", "meta", "validateOnMount", "helperText"]);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      loadOptionsChangeCounter = _useState2[0],
      setCounter = _useState2[1];

  var loadOptionsStr = fnToString(loadOptions);
  useEffect(function () {
    setCounter(loadOptionsChangeCounter + 1); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [loadOptionsStr]);
  var isSearchClear = isSearchable || isClearable;
  var Component = ClearedSelect;

  if (isMulti && isSearchClear) {
    Component = ClearedMultiSelectFilterable;
  } else if (isMulti) {
    Component = ClearedMultiSelect;
  } else if (isSearchClear) {
    Component = ClearedSelectSearchable;
  }

  var invalidText = (meta.touched || validateOnMount) && (meta.error || meta.submitError) || '';
  var text = (meta.touched || validateOnMount) && meta.warning || helperText;
  return /*#__PURE__*/React.createElement(DataDrivenSelect, _extends({
    SelectComponent: Component,
    simpleValue: false
  }, rest, input, {
    isMulti: isMulti,
    loadOptions: loadOptions,
    invalidText: invalidText,
    loadOptionsChangeCounter: loadOptionsChangeCounter,
    helperText: text
  }));
};

Select.propTypes = {
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    label: PropTypes.node
  }))
};
Select.defaultProps = {
  loadingMessage: 'Loading...'
};
export default Select;

==> carbon-component-mapper-3.18.5.tgz: package/esm/select/select.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _typeof from "@babel/runtime/helpers/typeof";
var _excluded = ["options"],
    _excluded2 = ["invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "isMulti", "classNamePrefix", "closeMenuOnSelect", "onChange", "originalOnChange", "carbonLabel", "placeholder", "isDisabled"],
    _excluded3 = ["invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "isMulti", "classNamePrefix", "closeMenuOnSelect", "onChange", "originalOnChange", "carbonLabel", "placeholder", "isDisabled"],
    _excluded4 = ["isSearchable", "isClearable", "isDisabled", "isMulti", "invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "classNamePrefix", "closeMenuOnSelect", "originalOnChange", "placeholder", "value"],
    _excluded5 = ["isSearchable", "isClearable", "isDisabled", "isMulti", "invalidText", "hideSelectedOptions", "noOptionsMessage", "onInputChange", "options", "isFetching", "invalid", "classNamePrefix", "closeMenuOnSelect", "originalOnChange", "placeholder", "labelText", "onChange", "value"],
    _excluded6 = ["isMulti", "isSearchable", "isClearable", "loadOptions", "input", "meta", "validateOnMount", "helperText"];
import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import DataDrivenSelect from '@data-driven-forms/common/select';
import fnToString from '@data-driven-forms/common/utils/fn-to-string';
import CarbonSelect from "carbon-components-react/es/components/Select/Select.js";
import MultiSelect from "carbon-components-react/es/components/MultiSelect/MultiSelect.js";
import SelectItem from "carbon-components-react/es/components/SelectItem/SelectItem.js";
import ComboBox from "carbon-components-react/es/components/ComboBox/ComboBox.js";
import SelectItemGroup from "carbon-components-react/es/components/SelectItemGroup/SelectItemGroup.js";
import prepareProps from '../prepare-props';

var onChangeWrapper = function onChangeWrapper(onChange) {
  return function (_ref) {
    var selectedItem = _ref.selectedItem,
        selectedItems = _ref.selectedItems;
    return onChange(selectedItems || selectedItem);
  };
};

export var getMultiValue = function getMultiValue(value, options) {
  return (Array.isArray(value) ? value : value ? [value] : []).map(function (item) {
    return _typeof(item) === 'object' ? item : options.find(function (_ref2) {
      var value = _ref2.value;
      return value === item;
    });
  });
};

var renderOptions = function renderOptions(options) {
  return options.map(function (option, index) {
    var options = option.options,
        rest = _objectWithoutProperties(option, _excluded);

    if (options) {
      return /*#__PURE__*/React.createElement(SelectItemGroup, _extends({
        key: rest.value || index,
        text: rest.label
      }, rest), renderOptions(options));
    }

    return /*#__PURE__*/React.createElement(SelectItem, _extends({
      key: rest.value || index,
      text: rest.label
    }, rest));
  });
};

var ClearedMultiSelectFilterable = function ClearedMultiSelectFilterable(_ref3) {
  var invalidText = _ref3.invalidText,
      hideSelectedOptions = _ref3.hideSelectedOptions,
      noOptionsMessage = _ref3.noOptionsMessage,
      onInputChange = _ref3.onInputChange,
      options = _ref3.options,
      isFetching = _ref3.isFetching,
      invalid = _ref3.invalid,
      isMulti = _ref3.isMulti,
      classNamePrefix = _ref3.classNamePrefix,
      closeMenuOnSelect = _ref3.closeMenuOnSelect,
      onChange = _ref3.onChange,
      originalOnChange = _ref3.originalOnChange,
      carbonLabel = _ref3.carbonLabel,
      placeholder = _ref3.placeholder,
      isDisabled = _ref3.isDisabled,
      rest = _objectWithoutProperties(_ref3, _excluded2);

  return /*#__PURE__*/React.createElement(MultiSelect.Filterable, _extends({
    disabled: isDisabled
  }, rest, {
    placeholder: carbonLabel || placeholder,
    onChange: onChangeWrapper(onChange),
    titleText: rest.labelText,
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText,
    items: options,
    initialSelectedItems: getMultiValue(rest.value, options)
  }));
};

ClearedMultiSelectFilterable.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  isDisabled: PropTypes.bool
};

var ClearedMultiSelect = function ClearedMultiSelect(_ref4) {
  var invalidText = _ref4.invalidText,
      hideSelectedOptions = _ref4.hideSelectedOptions,
      noOptionsMessage = _ref4.noOptionsMessage,
      onInputChange = _ref4.onInputChange,
      options = _ref4.options,
      isFetching = _ref4.isFetching,
      invalid = _ref4.invalid,
      isMulti = _ref4.isMulti,
      classNamePrefix = _ref4.classNamePrefix,
      closeMenuOnSelect = _ref4.closeMenuOnSelect,
      onChange = _ref4.onChange,
      originalOnChange = _ref4.originalOnChange,
      carbonLabel = _ref4.carbonLabel,
      placeholder = _ref4.placeholder,
      isDisabled = _ref4.isDisabled,
      rest = _objectWithoutProperties(_ref4, _excluded3);

  return /*#__PURE__*/React.createElement(MultiSelect, _extends({
    disabled: isDisabled
  }, rest, {
    label: carbonLabel || placeholder,
    onChange: onChangeWrapper(onChange),
    titleText: rest.labelText,
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText,
    items: options,
    initialSelectedItems: getMultiValue(rest.value, options)
  }));
};

ClearedMultiSelect.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  isDisabled: PropTypes.bool
};

var getSelectValue = function getSelectValue(value, isMulti) {
  return isMulti ? value : Array.isArray(value) ? value[0] : value;
};

var ClearedSelect = function ClearedSelect(_ref5) {
  var isSearchable = _ref5.isSearchable,
      isClearable = _ref5.isClearable,
      isDisabled = _ref5.isDisabled,
      isMulti = _ref5.isMulti,
      invalidText = _ref5.invalidText,
      hideSelectedOptions = _ref5.hideSelectedOptions,
      noOptionsMessage = _ref5.noOptionsMessage,
      onInputChange = _ref5.onInputChange,
      options = _ref5.options,
      isFetching = _ref5.isFetching,
      invalid = _ref5.invalid,
      classNamePrefix = _ref5.classNamePrefix,
      closeMenuOnSelect = _ref5.closeMenuOnSelect,
      originalOnChange = _ref5.originalOnChange,
      placeholder = _ref5.placeholder,
      value = _ref5.value,
      rest = _objectWithoutProperties(_ref5, _excluded4);

  return /*#__PURE__*/React.createElement(CarbonSelect, _extends({
    value: getSelectValue(value, isMulti),
    disabled: isFetching
  }, rest, {
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText
  }), isFetching && /*#__PURE__*/React.createElement(SelectItem, {
    text: placeholder,
    value: ''
  }), renderOptions(options));
};

ClearedSelect.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  isSearchable: PropTypes.bool,
  isClearable: PropTypes.bool,
  value: PropTypes.any
};

var getComboInitialValue = function getComboInitialValue(value) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var result = Array.isArray(value) ? value[0] : value;
  return _typeof(result) === 'object' ? result : options.find(function (_ref6) {
    var value = _ref6.value;
    return value === result;
  }) || result;
};
/**
 * Combobox cannot be multi value
 */


var ClearedSelectSearchable = function ClearedSelectSearchable(_ref7) {
  var isSearchable = _ref7.isSearchable,
      isClearable = _ref7.isClearable,
      isDisabled = _ref7.isDisabled,
      isMulti = _ref7.isMulti,
      invalidText = _ref7.invalidText,
      hideSelectedOptions = _ref7.hideSelectedOptions,
      noOptionsMessage = _ref7.noOptionsMessage,
      onInputChange = _ref7.onInputChange,
      _ref7$options = _ref7.options,
      options = _ref7$options === void 0 ? [] : _ref7$options,
      isFetching = _ref7.isFetching,
      invalid = _ref7.invalid,
      classNamePrefix = _ref7.classNamePrefix,
      closeMenuOnSelect = _ref7.closeMenuOnSelect,
      originalOnChange = _ref7.originalOnChange,
      placeholder = _ref7.placeholder,
      labelText = _ref7.labelText,
      onChange = _ref7.onChange,
      value = _ref7.value,
      rest = _objectWithoutProperties(_ref7, _excluded5);

  return /*#__PURE__*/React.createElement(ComboBox, _extends({
    disabled: isFetching
  }, rest, {
    id: rest.name,
    invalid: Boolean(invalidText),
    invalidText: invalidText,
    initialSelectedItem: getComboInitialValue(value, options),
    items: options,
    placeholder: placeholder,
    titleText: labelText,
    onChange: onChangeWrapper(onChange)
  }));
};

ClearedSelectSearchable.propTypes = {
  invalidText: PropTypes.node,
  hideSelectedOptions: PropTypes.any,
  noOptionsMessage: PropTypes.any,
  onInputChange: PropTypes.func,
  options: PropTypes.array,
  isFetching: PropTypes.bool,
  invalid: PropTypes.oneOfType([PropTypes.bool, PropTypes.node]),
  isMulti: PropTypes.bool,
  classNamePrefix: PropTypes.any,
  closeMenuOnSelect: PropTypes.any,
  onChange: PropTypes.func,
  originalOnChange: PropTypes.func,
  carbonLabel: PropTypes.node,
  placeholder: PropTypes.node,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  isSearchable: PropTypes.bool,
  isClearable: PropTypes.bool,
  labelText: PropTypes.string,
  value: PropTypes.any
};

var Select = function Select(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      isMulti = _useFieldApi.isMulti,
      isSearchable = _useFieldApi.isSearchable,
      isClearable = _useFieldApi.isClearable,
      loadOptions = _useFieldApi.loadOptions,
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      rest = _objectWithoutProperties(_useFieldApi, _excluded6);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      loadOptionsChangeCounter = _useState2[0],
      setCounter = _useState2[1];

  var loadOptionsStr = fnToString(loadOptions);
  useEffect(function () {
    setCounter(loadOptionsChangeCounter + 1); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [loadOptionsStr]);
  var isSearchClear = isSearchable || isClearable;
  var Component = ClearedSelect;

  if (isMulti && isSearchClear) {
    Component = ClearedMultiSelectFilterable;
  } else if (isMulti) {
    Component = ClearedMultiSelect;
  } else if (isSearchClear) {
    Component = ClearedSelectSearchable;
  }

  var invalidText = (meta.touched || validateOnMount) && (meta.error || meta.submitError) || '';
  var text = (meta.touched || validateOnMount) && meta.warning || helperText;
  return /*#__PURE__*/React.createElement(DataDrivenSelect, _extends({
    SelectComponent: Component,
    simpleValue: false
  }, rest, input, {
    isMulti: isMulti,
    loadOptions: loadOptions,
    invalidText: invalidText,
    loadOptionsChangeCounter: loadOptionsChangeCounter,
    helperText: text
  }));
};

Select.propTypes = {
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    label: PropTypes.node
  }))
};
Select.defaultProps = {
  loadingMessage: 'Loading...'
};
export default Select;
